from django.shortcuts import render

from blog.forms import CommentForm
from blog.models import Post, Comment


def blog_index(request):
    posts = Post.objects.all().order_by("-created_on")
    context = {"posts": posts}
    return render(request, "blog_index.html", context)


def blog_category(request, category):
    posts = Post.objects.filter(categories__name__contains=category).order_by(
        "-created_on"
    )
    context = {"category": category, "posts": posts}
    return render(request, "blog_category.html", context)


def blog_detail(request, pk):
    post = Post.objects.get(pk=pk)
    comments = Comment.objects.filter(post=post)

    form = CommentForm()
    if request.method == "POST":
        form = CommentForm(request.POST)
        if form.is_valid():
            comment = Comment(
                author=form.cleaned_data["author"],
                body=form.cleaned_data["body"],
                post=post,
            )
            comment.save()

    context = {"post": post, "comments": comments, "form": form}
    return render(request, "blog_detail.html", context)



from django.urls import path
from . import views

urlpatterns = [
    path("", views.blog_index, name="blog_index"),
    path("<int:pk>/", views.blog_detail, name="blog_detail"),
    path("<category>/", views.blog_category, name="blog_category"),
]



from django.db import models

from django_prometheus.models import ExportModelOperationsMixin

# Monitoring your models -- 'ExportModelOperationsMixin'


class Category(ExportModelOperationsMixin('category'), models.Model):
    name = models.CharField(max_length=20)

    def category(self):
        return self.name


class Post(ExportModelOperationsMixin('post'), models.Model):
    title = models.CharField(max_length=255)
    body = models.TextField()
    created_on = models.DateTimeField(auto_now_add=True)
    last_modified = models.DateTimeField(auto_now=True)
    categories = models.ManyToManyField("Category", related_name="posts")

    def post_title(self):
        return self.title

    def post_body(self):
        return self.body

    def post_created_on(self):
        return self.created_on

    def post_last_modified(self):
        return self.last_modified

    def post_categories(self):
        return self.categories


class Comment(ExportModelOperationsMixin('comment'), models.Model):
    author = models.CharField(max_length=60)
    body = models.TextField()
    created_on = models.DateTimeField(auto_now_add=True)
    post = models.ForeignKey("Post", on_delete=models.CASCADE)

    def comment_author(self):
        return self.author

    def comment_body(self):
        return self.body

    def comment_created_on(self):
        return self.created_on

    def comment_post(self):
        return self.post
